@@ -1,6 +1,7 @@
 """Registers precis_i18n codec."""
 
 import codecs
+
 from precis_i18n import get_profile
 
 
@@ -32,8 +33,9 @@ def search(name):
     except KeyError:
         return None
 
-    return codecs.CodecInfo(
-        name=name, encode=_make_encode(profile), decode=_not_supported)
+    return codecs.CodecInfo(name=name,
+                            encode=_make_encode(profile),
+                            decode=_not_supported)
 
 
 codecs.register(search)
